diff Core/Toolbox.h @ 4036:c6e82885f570

merge
author Alain Mazy <alain@mazy.be>
date Wed, 10 Jun 2020 10:28:15 +0200
parents 05a363186da6
children
line wrap: on
line diff
--- a/Core/Toolbox.h	Wed Jun 10 10:28:01 2020 +0200
+++ b/Core/Toolbox.h	Wed Jun 10 10:28:15 2020 +0200
@@ -58,6 +58,10 @@
 #  error The macro ORTHANC_ENABLE_PUGIXML must be defined
 #endif
 
+#if !defined(ORTHANC_ENABLE_SSL)
+#  error The macro ORTHANC_ENABLE_SSL must be defined
+#endif
+
 
 /**
  * NOTE: GUID vs. UUID
@@ -85,7 +89,7 @@
   class ORTHANC_PUBLIC Toolbox
   {
   public:
-    class LinesIterator
+    class ORTHANC_PUBLIC LinesIterator
     {
     private:
       const std::string& content_;
@@ -243,7 +247,7 @@
 #endif
 
     static void InitializeOpenSsl();
-    
+
     static void FinalizeOpenSsl();
 
     static std::string GenerateUuid();
@@ -272,8 +276,8 @@
 /**
  * The plain C, opaque data structure "OrthancLinesIterator" is a thin
  * wrapper around Orthanc::Toolbox::LinesIterator, and is only used by
  * "../Resources/WebAssembly/dcdict.cc", in order to avoid code
  * duplication
  **/
 
 struct OrthancLinesIterator;
@@ -272,8 +276,8 @@
  * The plain C, opaque data structure "OrthancLinesIterator" is a thin
  * wrapper around Orthanc::Toolbox::LinesIterator, and is only used by
- * "../Resources/WebAssembly/dcdict.cc", in order to avoid code
- * duplication
+ * "../Resources/Patches/dcmtk-dcdict_orthanc.cc", in order to avoid
+ * code duplication
  **/
 